@@ -5,14 +5,16 @@ CONFIG = {
         'name': 'hatchling',
         'description': 'Modern, extensible Python build backend',
         'readme': 'README.md',
+        'requires-python': '>=3.7',
+        'license': 'MIT',
         'authors': [{'name': 'Ofek Lev', 'email': 'oss@ofek.dev'}],
         'urls': {
             'Homepage': 'https://hatch.pypa.io/latest/',
+            'Funding': 'https://github.com/sponsors/ofek',
             'History': 'https://hatch.pypa.io/dev/history/',
             'Tracker': 'https://github.com/pypa/hatch/issues',
             'Source': 'https://github.com/pypa/hatch/tree/master/backend',
         },
-        'license': 'MIT',
         'keywords': ['build', 'hatch', 'packaging'],
         'classifiers': [
             'Development Status :: 5 - Production/Stable',
@@ -20,26 +22,23 @@ CONFIG = {
             'License :: OSI Approved :: MIT License',
             'Natural Language :: English',
             'Operating System :: OS Independent',
-            'Programming Language :: Python :: 2.7',
             'Programming Language :: Python :: 3.7',
             'Programming Language :: Python :: 3.8',
             'Programming Language :: Python :: 3.9',
             'Programming Language :: Python :: 3.10',
+            'Programming Language :: Python :: 3.11',
             'Programming Language :: Python :: Implementation :: CPython',
             'Programming Language :: Python :: Implementation :: PyPy',
             'Topic :: Software Development :: Build Tools',
             'Topic :: Software Development :: Libraries :: Python Modules',
         ],
         'dependencies': [
-            'editables>=0.3; python_version > "3"',
+            'editables>=0.3',
             'importlib-metadata; python_version < "3.8"',
-            'packaging>=21.3; python_version > "3"',
-            'packaging~=20.9; python_version < "3"',
+            'packaging>=21.3',
             'pathspec>=0.9',
-            'pluggy>=1.0.0; python_version > "3"',
-            'pluggy~=0.13; python_version < "3"',
-            'toml~=0.10.2; python_version < "3"',
-            'tomli>=1.2.2; python_version > "3" and python_version < "3.11"',
+            'pluggy>=1.0.0',
+            'tomli>=1.2.2; python_version < "3.11"',
         ],
         'scripts': {'hatchling': 'hatchling.cli:hatchling'},
         'dynamic': ['version'],
@@ -56,7 +55,7 @@ def build_sdist(sdist_directory, config_settings=None):
     """
     https://peps.python.org/pep-0517/#build-sdist
     """
-    from .builders.sdist import SdistBuilder
+    from hatchling.builders.sdist import SdistBuilder
 
     builder = SdistBuilder(os.getcwd(), config=CONFIG)
     return os.path.basename(next(builder.build(sdist_directory, ['standard'])))
@@ -66,7 +65,7 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
     """
     https://peps.python.org/pep-0517/#build-wheel
     """
-    from .builders.wheel import WheelBuilder
+    from hatchling.builders.wheel import WheelBuilder
 
     builder = WheelBuilder(os.getcwd(), config=CONFIG)
     return os.path.basename(next(builder.build(wheel_directory, ['standard'])))
@@ -76,7 +75,7 @@ def build_editable(wheel_directory, config_settings=None, metadata_directory=Non
     """
     https://peps.python.org/pep-0660/#build-editable
     """
-    from .builders.wheel import WheelBuilder
+    from hatchling.builders.wheel import WheelBuilder
 
     builder = WheelBuilder(os.getcwd(), config=CONFIG)
     return os.path.basename(next(builder.build(wheel_directory, ['editable'])))
